#
# spec file for package octave
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define apiver  v59
# Required for RC builds, in this case version contains ~rc, src_ver -rc
%define pkg_ver 9.2.0
%define src_ver %{pkg_ver}
# Image processing library
%if 0
# currently, octave cannot be built against ImageMagick 7
%bcond_without imagemagick
%else
# Default variant - GraphicsMagick
%bcond_with imagemagick
%endif
# Use native graphics or gnuplot
%bcond_without native_graphics
# Build GUI
%bcond_without gui
# JIT compilation
%bcond_with jit
# JAVA support
%bcond_without java
# Sound IO
%bcond_without sound
# Allow building without openBLAS, e.g. for architectures
# like RISC-V where openBLAS is not available
%bcond_without openblas
%if %{with openblas}
%define blas_library openblas
%else
%define blas_library blas
%endif
Name:           octave
Version:        %{pkg_ver}
Release:        1.4
Summary:        A High Level Programming Language
License:        GPL-3.0-or-later
Group:          Productivity/Scientific/Math
URL:            https://www.octave.org/
Source0:        https://ftp.gnu.org/gnu/octave/%{name}-%{src_ver}.tar.lz
Source1:        octave.macros
Source2:        %{name}-rpmlintrc
# PATCH-FIX-OPENSUSE
Patch0:         octave_tools_pie.patch
# PATCH-FIX-UPSTREAM - https://savannah.gnu.org/bugs/?54607
Patch1:         0001-Disable-signal-handler-thread-avoid-duplicate-signal.patch
#
BuildRequires:  %{blas_library}-devel
BuildRequires:  arpack-ng-devel
# Required for Patch0
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  dejagnu
BuildRequires:  fdupes
BuildRequires:  fftw3-threads-devel
BuildRequires:  flex
BuildRequires:  gcc-c++
BuildRequires:  gcc-fortran
BuildRequires:  ghostscript
BuildRequires:  glpk-devel
BuildRequires:  gmp-devel
BuildRequires:  gperf
BuildRequires:  hdf5-devel
BuildRequires:  lapack-devel
BuildRequires:  libtool
BuildRequires:  lzip
# required for help/doc called from the tests
BuildRequires:  makeinfo
BuildRequires:  pcre-devel
BuildRequires:  pkgconfig
BuildRequires:  qhull_r-devel
BuildRequires:  qrupdate-devel
BuildRequires:  readline-devel
BuildRequires:  suitesparse-devel
BuildRequires:  sundials-devel
# Tests build requires
BuildRequires:  unzip
BuildRequires:  xvfb-run
BuildRequires:  zip
BuildRequires:  pkgconfig(RapidJSON)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(zlib)
Requires:       octave-cli = %{version}
Requires(pre):  update-alternatives
%if %{with imagemagick}
BuildRequires:  pkgconfig(Magick++)
%else
BuildRequires:  pkgconfig(GraphicsMagick++)
%endif
# GUI build requires
%if %{with gui}
BuildRequires:  desktop-file-utils
BuildRequires:  hicolor-icon-theme
BuildRequires:  qscintilla-qt6-devel
BuildRequires:  qt6-tools-helpgenerators
BuildRequires:  qt6-tools-linguist
BuildRequires:  update-desktop-files
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Core5Compat)
BuildRequires:  cmake(Qt6Gui)
BuildRequires:  cmake(Qt6Help)
BuildRequires:  cmake(Qt6Network)
BuildRequires:  cmake(Qt6OpenGL)
BuildRequires:  cmake(Qt6OpenGLWidgets)
BuildRequires:  cmake(Qt6PrintSupport)
BuildRequires:  cmake(Qt6Widgets)
BuildRequires:  cmake(Qt6Xml)
# Section testing
BuildRequires:  xorg-x11-Xvfb
%if %{without native_graphics}
BuildRequires:  gnuplot
%endif
# \Section
# boo#1095605
Requires:       qt6-sql-sqlite
Obsoletes:      octave-gui < 4.0
Provides:       octave-gui = %{version}
%endif
# Sound IO build requires
%if %{with sound}
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(portaudio-2.0)
BuildRequires:  pkgconfig(sndfile)
%endif
# JAVA functions build requires
%if %{with java}
BuildRequires:  java-devel
%endif
# JIT build requires
%if %{with jit}
BuildRequires:  llvm-devel
%endif
# Native graphics build requires
%if %{with native_graphics}
BuildRequires:  Mesa-devel
BuildRequires:  Mesa-dri
BuildRequires:  fltk-devel
BuildRequires:  gl2ps-devel
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(glu)
%else
Requires:       gnuplot
%endif

%description
Octave is a high level programming language. It is designed for the
solution of numeric problems.
%if %{with gui}

This package contains the graphical user interface.
%endif

%package        cli
Summary:        Command-line user interface for Octave
Group:          Productivity/Scientific/Math
Requires:       makeinfo
Requires(pre):  update-alternatives
Recommends:     octave-doc = %{version}
# SECTION Resolve degeneracy between multiple libsundials_{sunlinsol,ida}.so providers from serial and parallel flavours of sundials
Requires:       %(rpm -qR sundials-devel | grep -oP "libsundials_ida[0-9]")
Requires:       %(rpm -qR sundials-devel | grep -oP "libsundials_sunlinsol[0-9_]+")
# /SECTION
%if %{with native_graphics}
Recommends:     epstool
Recommends:     pstoedit
# transfig requires texlive installation now
# Recommends:     transfig
%endif

%description    cli
Octave is a high level programming language. It is designed for the
solution of numeric problems.

This package contains the command-line user interface.

%package        devel
Summary:        Development files for Octave
Group:          Development/Languages/Other
Requires:       %{blas_library}-devel
Requires:       %{name}-cli = %{version}
Requires:       fftw3-devel
Requires:       fftw3-threads-devel
Requires:       gcc-c++
Requires:       gcc-fortran
Requires:       hdf5-devel
Requires:       make

%description    devel
Octave is a high level programming language. It is designed for the
solution of numeric problems.

This package contains all necessary include files and libraries needed
to develop applications using Octave.

%package        doc
Summary:        Documentation for Octave
Group:          Documentation/Other
BuildArch:      noarch

%description    doc
Octave is a high level programming language. It is designed for the
solution of numeric problems.

This package contains documentation for Octave.

%prep
%setup -q -n %{name}-%{src_ver}
%autopatch -p1

%build

# rebuild makefiles after Patch0
autoreconf -i -s -f
%configure \
  --libexecdir=%{_libdir} \
%if %{with imagemagick}
  --with-magick=Magick++\
%else
  --with-magick=GraphicsMagick++\
%endif
  %{?with_gui: --with-qt} \
  %{!?with_gui: --without-qt} \
  %{?with_jit: --enable-jit} \
  %{!?with_java: --disable-java} \
  --with-blas=%{blas_library} \
  --disable-docs \
  --enable-openmp

%make_build

%install
%make_install
# see bnc#557340
mkdir -p %{buildroot}/%{_sysconfdir}/ld.so.conf.d
echo %{_libdir}/%{name}/%{src_ver} > %{buildroot}/%{_sysconfdir}/ld.so.conf.d/%{name}.conf
find %{buildroot} -type f -name "*.la" -delete -print
# local rc file into /etc
mkdir %{buildroot}/%{_sysconfdir}/%{name}
mv %{buildroot}/%{_datadir}/%{name}/site/m/startup/octaverc %{buildroot}/%{_sysconfdir}/%{name}
ln -s %{_sysconfdir}/%{name}/octaverc %{buildroot}/%{_datadir}/%{name}/site/m/startup/octaverc
#
mkdir -p %{buildroot}/%{_libdir}/%{name}/packages
mkdir -p %{buildroot}/%{_datadir}/%{name}/packages
# Documentation
install -Dm 644 -t %{buildroot}%{_mandir}/man1/ doc/*/*.1
install -Dm 644 -t %{buildroot}%{_infodir} doc/*/*.info doc/*/*.info-*
# Remove icons with huge size, we have scalable SVGs
rm -rf %{buildroot}/%{_datadir}/icons/hicolor/1024x1024
# gui related fixes
%if %{without gui}
rm -rf %{buildroot}/%{_datadir}/icons/hicolor/
rm -rf %{buildroot}/%{_datadir}/metainfo/
rm -rf %{buildroot}/%{_datadir}/applications/
%endif
# rpm macros
install -Dm 644 %{SOURCE1} %{buildroot}%{_rpmmacrodir}/macros.octave
# substitute correct values for octave_blas macros
sed -i 's/OCTAVE_BLAS_LIBRARY_NAME/%{blas_library}/g' %{buildroot}%{_rpmmacrodir}/macros.octave

# increase stack size set by the JVM, affects the whole octave process
echo "-Xss8m" >  %{buildroot}/%{_datadir}/%{name}/%{src_ver}/m/java/java.opts

%fdupes %{buildroot}%{_datadir}/octave/

%check
# Increase stack limits. OpenBLAS tests are run after some JVM test, and OpenBLAS
# dgetrf is quite memory hungry, see https://github.com/xianyi/OpenBLAS/issues/246
echo "-Xss8m" >  scripts/java/java.opts

# We need "--no-gui-libs" as a temporary work around to https://savannah.gnu.org/bugs/index.php?65866
xvfb-run make %{?_smp_mflags} check RUN_OCTAVE_OPTIONS="--no-gui-libs"

%ldconfig_scriptlets

%post cli
/sbin/ldconfig
%install_info --info-dir=%{_infodir} %{_infodir}/octave.info.gz

%postun cli
/sbin/ldconfig
%install_info_delete --info-dir=%{_infodir} %{_infodir}/octave.info.gz

%files
%license COPYING
%doc AUTHORS BUGS NEWS
%doc README ChangeLog
%if %{with gui}
%{_libdir}/%{name}/%{src_ver}/exec/*-*-linux-gnu*/octave-gui
%{_libdir}/%{name}/%{src_ver}/exec/*-*-linux-gnu*/octave-svgconvert
%{_libdir}/%{name}/%{src_ver}/liboctgui.so.*
%{_datadir}/%{name}/%{src_ver}/locale/
%{_datadir}/metainfo/*.xml
%{_datadir}/applications/*.desktop
%{_datadir}/icons/hicolor/*/apps/octave.*
%endif

%files cli
%{_bindir}/octave
%{_bindir}/octave-%{src_ver}
%{_bindir}/octave-cli
%{_bindir}/octave-cli-%{src_ver}
%{_mandir}/man1/octave.1%{?ext_man}
%{_mandir}/man1/octave-cli.1%{?ext_man}
%{_bindir}/octave-config
%{_bindir}/octave-config-%{src_ver}
%{_mandir}/man1/octave-config.1%{?ext_man}
%{_infodir}/*.gz
%config %{_sysconfdir}/ld.so.conf.d/%{name}.conf
%config(noreplace) %{_sysconfdir}/%{name}/octaverc
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/%{src_ver}
%dir %{_libdir}/%{name}/packages
%dir %{_datadir}/%{name}/packages
%dir %{_sysconfdir}/%{name}
%{_libdir}/%{name}/%{src_ver}/oct
%{_libdir}/%{name}/%{src_ver}/liboctave.so.*
%{_libdir}/%{name}/%{src_ver}/liboctinterp.so.*
%if %{with gui}
%dir %{_libdir}/%{name}/%{src_ver}/exec/
%dir %{_libdir}/%{name}/%{src_ver}/exec/*-*-linux-gnu*/
%exclude %{_datadir}/%{name}/%{src_ver}/locale/
%endif
%{_datadir}/octave/
%{_libdir}/%{name}/site

%files devel
%{_bindir}/mkoctfile
%{_bindir}/mkoctfile-%{src_ver}
%{_mandir}/man1/mkoctfile.1%{?ext_man}
%{_includedir}/*
%{_libdir}/%{name}/%{src_ver}/lib*.so
%{_libdir}/%{name}/api-%{apiver}
%{_libdir}/pkgconfig/octave.pc
%{_libdir}/pkgconfig/octinterp.pc
%{_rpmmacrodir}/macros.octave

%files doc
%doc doc/interpreter/octave.pdf
%doc doc/liboctave/liboctave.pdf
%doc doc/refcard/refcard-a4.pdf
%doc doc/refcard/refcard-legal.pdf

%changelog
* Mon Jun 10 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 9.2.0:
  * Improvements and fixes:
  - hist.m: Add input validation for Y restricting it to 2-D
    array (bug #65478). Avoid error when Y value range is very
    small (bug #65714).
  - cross.m: Add input validation for dim restricting it to a
    numeric integer valued scalar (bug #65544, bug #65527).
  - getframe.m: Respect pixel ratio (high DPI) of screen with
    figure (bug #65540).
  - legend.m: Fix error if root property "showhiddenhandles" is
    "on" (bug #65442)
  - savepath.m: Correctly handle packages without binaries (bug
    [#65559]).
  - Correctly scale figure position on screen with DPI scaling
    (high DPI).
  - profile ('on') now clears any existing profile data as the
    documentation states (bug #65595).
  - Fix segmentation fault when trying to set breakpoint in
    non-existent method of classdef class (bug #65610).
  - Improve default display of classdef properties (bug #62432).
  - Avoid crash with Qt6 6.7.0 (bug #65605).
  - bar.m: Catch input number validation error.
  - Prevent OOM crash or segmentation fault in sort () when dim
    equals Inf (bug #65712).
  - legend.m: Avoid setting more colors than coordinates for
    patch objects (bug #65632).
  - inputParser.m: Allow default classdef objects which overload
    struct (bug #65667).
  - Preserve "position" property of figure when object is
    reset() (bug #65750).
  - hist.m: Avoid error when y value range is very small (bug
    [#65714]).
  - barh: Add input validation check for nargin < 1.
  * GUI:
  - Use first word for options in right-click menu of command
    window widget (bug #65518).
  - Set DontUseNativeDialog flag as first property in
    QFileDialog.
  - Explicitly raise non-modal message boxes ensuring
    visibility.
  - Save and restore splitter state of documentation widget.
  - Allow executing new files from built-in editor with F5 (bug
    [#65548]).
  - Allow unbinding GUI shortcuts (bug #65580).
  - Fix restoring headers in file browser and workspace view
    (bug #65030).
  - File dialogs of the built-in editor are now modal.
  - Fix dragging editor from main window into floating state
    (bug #65725).
  * Build system / Tests:
  - Avoid overriding save_* variables from outer scope (bug
    [#65476]). This fixes an error that might have lead to
    overlinking of shared libraries (e.g., .oct files). Consider
    rebuilding shared libraries that have been built with Octave
    9.1.0.
  - Add BIST for is_valid_file_id.m (bug #65543).
  - Update metainfo.xml with new fields for AppStream 1.0 (bug
    [#65355]).
  - Show result of check for std::pmr::polymorphic_allocator in
    configure summary.
  - Run test program for polymorphic allocators if possible
    instead of a simple build check.
  - Speed up BIST for the central part of convn with 'full'
    shape.
  - Require Qt Widgets module when building the GUI (bug
    [#65625]).
  - bug-53027.tst: Delete temporary file after test is done (bug
    [#53027]).
  - Avoid build error with GCC 14 when targeting Windows.
  - Try to clean up after BIST also in case test failed (bug
    [#53027]).
  - bar.m, barh.m: Add plotting BISTs (bug #65671).
  - Check if C and Fortran compilers accept -fexceptions flag
    (bug #65767). This affects building Octave itself from
    sources and also how .mex or .oct files are built by mex and
    mkoctfile.
  * Documentation updates.
- Changes from version 9.1.0:
  * Long list, see <https://octave.org/NEWS-9.html>
- Switch to Qt6 library for GUI.
- Tests: Need to pass `RUN_OCTAVE_OPTIONS="--no-gui-libs"` as a
  temporary work around to
  <https://savannah.gnu.org/bugs/index.php?65866>
- Add BuildRequires: gnuplot when building without
  `native_graphics`; it is needed for tests.
* Thu Nov 16 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 8.4.0:
  * mkoctfile: Skip parsing for less flags (bug #64590).
  * Fix getting number of non-zero elements in SuiteSparse
    matrices.
  * delaunayn: Avoid erroneous simplex removal for integer inputs
    (bug #64658).
  * delaunayn: Add precision loss warning for large int inputs
    (bug #64658).
  * delaunayn: Also warn for negative integers with large
    magnitude (bug #64658).
  * Correctly load all-zero sparse matrices from text files (bug
    [#64696]).
  * Allocate correct storage for interleaved complex mxArray
    objects (bug #64687).
  * mkoctfile: Prefer parsing over passing on argument after
    unknown argument (bug #64725).
  * fft: Avoid segmentation fault with ND-arrays (bug #64729).
  * fft: Avoid overwriting input for inplace operations (bug
    [#64733]).
  * intersect.m: Correct third output with "stable" flag (bug
    [#60347]).
  * Avoid use-after-free issue in parser (bug #60882).
  * betainc.m: Improve integer input logic and validation (bug
    [#64726]).
  * webread: Apply timeout also for initial connection (bug
    [#64826]).
  * mkpp.m: Remove stray text causing error with demo code.
  * Ensure that new test for saving sparse matrices writes a text
    file.
  * Search for tests in and install octave-value template sources
    (bug #64696).
  * Correct variable name typo in documentation of slice().
  * Expand documentation for gcd() and lcm().
  * datevec: Clarify that heuristics are used to detect the format
    of a date string (bug #64563).
  * datenum: Add help text that inputs can be arrays, add examples
    (bug #54679).
  * datevec: Add help text that inputs can be arrays (bug #54679).
  * Describe various pitfalls with floating point ranges (bug
    [#64692]).
  * Add range example and some copyedits.
* Wed Oct 25 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Drop termap BuildRequireS: no longer needed.
* Thu Oct 19 2023 Atri Bhattacharya <badshah400@gmail.com>
- octave.macros: For %%octave_pkg_install, set HOME to current
  working dir to avoid permission issues when octave tries to
  update list of installed packages in its config file.
* Tue Aug 29 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 8.3.0:
  * undo_string_escapes: Return '\0' for NUL byte input (bug
    [#64051]).
  * Stop excessive memory usage for minor grid ticks (bug #64017).
  * Include needed headers in installed .cc files (bug #63922).
  * Fix floating point exception when sparse array reshaped to 0x0
    (bug #64080).
  * unicode2native: Fix conversion to UTF-16 (bug #64139).
  * memory: Fix execution on Cygwin.
  * uniconv-wrappers: Avoid freeing uninitialized pointer (bug
    [#64182]).
  * lo-regexp.cc: Only include PCRE2/PCRE headers if feature test
    succeeded (bug #64172).
  * Fix segfault when saveobj() used with old-style class files
    (bug #64220).
  * Fix restoring breakpoints from dbstatus breakpoint structure
    (bug #64271).
  * colorbar.m: Fix undefined variable d (bug #64287).
  * Reset all axes properties except 'Units' and 'Position' with
    cla ('reset').
  * unicode2native.m: Restore support for one input parameter (bug
    [#64331]).
  * native2unicode, unicode2native: Support empty second argument
    (bug #64331).
  * fullfile.m: Return empty cell for input with empty cell (bug
    [#64377]).
  * audioplayer.m: Emit error if input data Y is empty (bug
    [#64379]).
  * Remove obsolete callback constructor code for @audioplayer and
    @audiorecorder (bug #64379).
  * Avoid false detection of “non-real pivot” in ichol() (bug
    [#63785]).
  * Fix building against SuiteSparse 7.1.0 when SPQR is disabled
    (bug #64446).
  * ellipsoid.m: Avoid returning geometry data unless it is
    explicitly requested to avoid overwriting ans.
  * subsasgn: Avoid panic on invalid field names (bug #64213).
  * lex.ll: Remove $ as a valid character for identifiers.
  * fileparts.m: Allow for relative path on different drive on
    Windows (bug #64462).
  * datevec.m: Add some ISO 8601 conform formats (patch #9964).
  * betaincinv.m: Slightly increase test tolerance (for macOS 13).
  * colorbar.m: Add tests (bug #64287).
  * sparse-qr.cc: Fix compatibility with SuiteSparse 7.1.0 /
    CXSparse 4.0.4.
  * pcg.m: Use eps tolerance in test for ishermitian (bug #63787).
  * fileparts.m: Overhaul BISTs.
  * Return documentation for help properties (bug #64067).
  * Add note to isprime.m on inputs over 2^64.
* Tue Apr 18 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 8.2.0:
  * fopen: Use “UTF-8” as default encoding for fopen
    (https://savannah.gnu.org/bugs/?63930).
  * fopen, unicode2native: Fix converting the encoding of short
    char arrays with invalid UTF-8
    (https://savannah.gnu.org/bugs/?63930).
  * fopen: Try to gather complete UTF-8 surrogates when converting
    encoding (https://savannah.gnu.org/bugs/?63930).
  * fopen: Do not convert encoding for file streams with libc++
    (https://savannah.gnu.org/bugs/?63930).
  * pr-output.cc: Fix output for format native-bit
    (https://savannah.gnu.org/bugs/?63940).
  * Fix evaluation of & and | expressions in conditional contexts
    (https://savannah.gnu.org/bugs/?63935).
  * Avoid clang warning about very unlikely buffer overflow.
  * mpoles.m: Overhaul function and use absolute tolerance for
    zero poles (https://savannah.gnu.org/bugs/?63937).
  * perms.m: Change "unique" output order to reverse lexicographic
    to match non-unique order
    (https://savannah.gnu.org/bugs/?63962).
  * Remove trailing '\r' from curl dir list
    (https://savannah.gnu.org/bugs/?63851).
  * Fix display of scalar complex variables with mixed Inf/NaN and
    floating point values (https://savannah.gnu.org/bugs/?63961).
  * Don’t use encoding facet when writing bytes to stream
    (https://savannah.gnu.org/bugs/?63931).
  * GUI: Speedup loading and saving preferences dialog
    (https://savannah.gnu.org/bugs/?63909).
  * Build system / Tests:
  - inpolygon.m: Fix demo code
    (https://savannah.gnu.org/bugs/?63865).
  - if.tst: New test for (https://savannah.gnu.org/bugs/?63935).
  - acinclude.m4: Correct typo in #define PCRE2_CODE_UNIT_WIDTH.
  - lu: Add self-test with complex valued input.
  - Disable visibility flags by default
    (https://savannah.gnu.org/bugs/?61855, bug #63916).
  - Check whether using STL from LLVM or Apple
    (https://savannah.gnu.org/bugs/?63930).
  - Documentation:
  - Improve documentation for linspace and logspace functions.
  - Correct and improve documentation for sparse() function.
* Sun Mar 12 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 8.1.0:
  * Long list of changes, see <https://octave.org/NEWS-8.html>.
- API version bumped from 57 to 58.
- Minor re-base of
  0001-Add-explicit-ctime-include-required-for-clock.patch for
  update (file-name change only).
* Wed Jan  4 2023 pgajdos@suse.com
- back to GraphicsMagick, octave cannot be built against
  ImageMagick 7
* Mon Dec 19 2022 pgajdos@suse.com
- GraphicsMagick will be removed from Factory
* Tue Nov 22 2022 Andreas Schwab <schwab@suse.de>
- Use xvfb-run for testsuite
* Wed Nov  9 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 7.3.0:
  * scanf: Don’t set error when reaching end of stream (bug
    [#62723]).
  * Fix duplicate names displayed with mixed @class/classdef
    classes (bug #62802).
  * canonicalize_file_name: Handle symlinks to UNC network shares
    (bug #62847).
  * canonicalize_file_name: Generalize check for mapped network
    drive (bug #62847).
  * fortran_vec: Fix instances of method chaining that may cause
    dangling pointer.
  * Fix wrong color in PDF printout of some LaTeX strings (bug
    [#62884]).
  * unpack.m: Escape backslashes in paths on Windows (bug #62888).
  * canonicalize_file_name: Check root of potential mapped network
    drive (bug #62847).
  * nextpow2.m: Fix for input between 0.5 and 1 (bug #62947).
  * quad2d: Fix unintended complex conjugate return (bug #62972).
  * Make sure we don’t pass short 8.3 path to latex on Windows
    (bug #62779).
  * canonicalize_file_name: Trim trailing file separators from
    root of mapped network drive (bug #62847).
  * imformats.m: Fix isa function in return value (bug #62974).
  * pie3: Fix “Too many input” args error.
  * Accept negative inputs to -2^63 for dec2bin and dec2hex (bug
    [#63089]).
  * Fix incorrect lambda outputs for lsqnonneg and pqpnonneg (bug
    [#63178]).
  * addtodate.m: Fix wrong month returned when subtracting a month
    from some end-of-month dates (bug #60671).
  * var.m: Fix some Inf and NaN inputs returning 0 instead of NaN
    (bug #63203)
  * var.m: Fix automatic broadcasting error for sparse and
    diagonal matrix inputs with vector weighting (bug #63291).
  * legend.m: Fix error with contour plot containing clabels (bug
    [#63262]).
  * dec2bin.m: Fix input validation (bug #63089).
  * glpk.m: Avoid using isfinite on potentially sparse input.
  * var.m: Use bsxfun rather than broadcasting with vector
    weighting (bug #63291).
  * Fix out of bound indexing in in-place broadcasting operations
    (bug #63303).
  * Respect confirmation when deleting files in file browser
    widget (bug #63198).
  * io.tst: Add test case for scanf (bug #62723).
  * nextpow2.m: Add bug number tag to regression tests (bug
    [#62947]).
  * quad2d.m: Add BIST to cset b0e90ca8e679 (bug #62972).
  * Add test for number of methods with classdef in @folder (bug
    [#62802]).
  * Use Autoconf macro to find egrep executable.
  * Documentation fixes.
- Add octave-rpmlintrc file to suppress false positives.
* Fri Sep 16 2022 Atri Bhattacharya <badshah400@gmail.com>
- octave-cli: Fix Requires after sundials main library was split
  into multiple shared libs.
- Update _constraints: Upto 10 GiB now required.
* Mon Aug 22 2022 Markus Ebner <info@ebner-markus.de>
- Update to version 7.2.0:
  * Long list of changes, see
    <https://octave.org/news/release/2022/07/28/octave-7.2.0-released.html>
- Drop upstreamed patches:
  * 0001-Add-explicit-ctime-include-required-for-clock.patch
  * fix_build_unlink_failed.patch
* Mon Jul 11 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix build with latest TW, add
  0001-Add-explicit-ctime-include-required-for-clock.patch
* Wed Jul  6 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix build of external packages when trying to unlink
  non-existent files, add fix_build_unlink_failed.patch
* Tue Jul  5 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Dynamically generate the dependencies on the correct
  libsundials/libsundials_ida package: the so-version can change
  over time.
* Sun Apr 10 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 7.1.0:
  * Long list of changes, see
    <https://www.gnu.org/software/octave/NEWS-7.html>.
- Drop upstreamed patches:
  * octave-fullscreen-with-multiple-monitors.patch
  * 0001-Use-reentrant-libqhull_r.patch
  * octave-qhull_r-fixes.patch
- New BuildRequires: Mesa-dri (needed for a test),
  pkgconfig(RapidJSON) (for JSON R/W support).
- Minor rebase of octave_tools_pie.patch to apply cleanly.
- Update _constraints: At least 8 GB disk space needed for 64-bit
  archs (x86_64 and aarch64).
* Tue Mar  8 2022 Atri Bhattacharya <badshah400@gmail.com>
- Add octave-fullscreen-with-multiple-monitors.patch -- fix
  maximized start on systems with two monitors
  (https://savannah.gnu.org/bugs/?61172); patch taken from
  upstream commit and re-based for version 6.4.0.
* Fri Nov  5 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 6.4.0:
  * Improvements and fixes:
  - Reduce memory usage in BISTs for copyobj, hgsave (bug
    [#57591]).
  - hgsave.m, copyobj.m: Use 'qt' graphics toolkit in BISTs.
  - main.cc: Use getopt to parse command line arguments (bug
    [#60886]).
  - main.cc: Remove invalid case (bug #60886).
  - Disable getopt error reporting in wrapper program (bug
    [#60886]).
  - interp1.m: Don’t interpret later numeric input as xi (bug
    [#60967]).
  - pkg: Improve similar package name suggestion (bug #61067).
  - Store parent name in function object when caching parents in
    scope (bug #61105).
  - Avoid internal error and segfault with eval and scripts (bug
    [#61191]).
  - rmpath: Prevent removing the current directory from the load
    path (bug #61216).
  * GUI:
  - Fix missing interpreter event in octave-scintilla.
  - Fix opening a file in a custom editor (bug #60990).
  * Documentation:
  - Improve docstring for disable_diagonal_matrix,
    disable_diagonal_matrix, and disable_range (patch #10089).
  - cbrt: Clarify that function errors for non-real input.
  - dsearchn.m: Added optional distance output description (bug
    [#61156]).
  - Add Hungarian translation for project description files.
  - Document fsolve output “info” -2 (bug #61310).
  * Build system: Correct error message for incompatible CXSparse
    (bug #61385).
- Refresh 0001-Use-reentrant-libqhull_r.patch for version 6.4.0
  (line offset changes only).
- Substitute OCTAVE_BLAS_LIBRARY_NAME value in installed macros
  file rather than modifying the source file itself.
* Wed Jul 28 2021 Andre C. Barros <andre.cbarros@yahoo.com>
- Upgrade to octave 6.3.0:
  * Long list of changes, see
    https://www.gnu.org/software/octave/news/release/2021/07/11/octave-6.3.0-released.html
- Update 0001-Use-reentrant-libqhull_r.patch for use with version
  6.3.0
- Add octave-qhull_r-fixes.patch to complement
  0001-Use-reentrant-libqhull_r.patch for the build system.
* Thu May  6 2021 Andreas Stieger <andreas.stieger@gmx.de>
- move rpm macros to /usr/lib/rpm/marcos.d (boo#1185659)
* Fri Apr  2 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix incomplete geometry support, use reentrant libqhull_r instead
  of the deprecated non-reentrant, add
  0001-Use-reentrant-libqhull_r.patch
* Mon Feb 22 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 6.2.0:
  * Bug fix release, see
    https://www.gnu.org/software/octave/news/release/2021/02/20/octave-6.2.0-released.html
* Wed Dec  2 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 6.1.0:
  * Long list of changes, see
    https://www.gnu.org/software/octave/NEWS-6.1.html
- Add BuildRequires: sundials-devel to enable sundials based
  solvers; also add libsundials*.so to Requires for octave-cli to
  resolve between multiple providers coming from serial and
  different parallel flavours of sundials.
- Update api version to 55 in keeping with upstream.
- Minor adjustment of patches to fix line offsets.
- Drop external pkgconfig file: octave now installs its own.
- Link duplicate files in %%{_datadir} using fdupes.
* Thu Aug 20 2020 Martin Liška <mliska@suse.cz>
- Use memoryperjob constraint instead of %%limit_build macro.
* Mon Feb 17 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Avoid stealing SIGCHLD from QProcess::waitForFinished, which
  causes the KDE file dialogs to hang up to the 30s default timeout.
  This only happens when a samba server is installed locally.
  Fixes https://savannah.gnu.org/bugs/?54607
  * 0001-Disable-signal-handler-thread-avoid-duplicate-signal.patch
- Add Xvfb build dependency for make check, several tests fail
  otherwise.
* Sun Feb 16 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Readd makeinfo to the build dependencies, called by octaves
  doc/help functions from the tests. Disable doc generation
  explicitly, otherwise it tries even without all tools present.
* Sun Feb  9 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 5.2.0
  This version is a bug fixing release, for details see:
  https://www.gnu.org/software/octave/news/release/2020/01/31/octave-5.2.0-released.html
- Drop upstream patches:
  * octave-bug-55029-fix_pause_and_kbhit_with_glibc_2_28.patch
  * octave-bug-56533-Cursor_misplaced_when_entering_newline_in_editor_with_tabs_indentation-part1.patch
  * octave-bug-56533-Cursor_misplaced_when_entering_newline_in_editor_with_tabs_indentation-part2.patch
- Use documentation from upstream tarball, no need to rebuild locally.
- Cleanup spec file, remove conditionals for EOLed distributions.
* Wed Nov 27 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix octave_pkg_test in RPM octave.macros, unpack pkg tarball
  again, as the target directory is removed by 'pkg build'.
* Fri Jul  5 2019 UTC - Markus Ebner <hiwatari.seiji@gmail.com>
- Backport fix: Cursor misplaced when entering newline in editor with tabs indentation
  behavior (bug #56533)
  * Added octave-bug-56533-Cursor_misplaced_when_entering_newline_in_editor_with_tabs_indentation-part1.patch
  * Added octave-bug-56533-Cursor_misplaced_when_entering_newline_in_editor_with_tabs_indentation-part2.patch
* Mon May 13 2019 Duncan Mac-Vicar <dmacvicar@suse.de>
- Backport fix: pause and kbhit with glibc 2.28 end-of-file state
  behavior (bug #55029)
  * Added octave-bug-55029-fix_pause_and_kbhit_with_glibc_2_28.patch
* Mon Mar  4 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 5.1.0
  * Long list of changes: see
    https://www.gnu.org/software/octave/NEWS-5.1.html
    https://www.gnu.org/software/octave/news/release/2019/03/01/octave-5.1-released.html
- Rebase octave_tools_pie.patch
- Add conditional building with blas instead of openBLAS. Allows building
  for architectures like RISC-V where openBLAS is not available (and probably
  never will, RISC-V vector instructions do not fit the openBLAS model).
* Fri Feb 15 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add %%limit_build to avoid build failures
* Thu Jan 10 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Only set -fpie for octave executables, as LDFLAGS is set as link flag
  in mkoctfile as default flags, leading to failing module builds.
  Add octave_tools_pie.patch
* Thu Jan  3 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 4.4.1
  * Long list of changes: see
    https://www.gnu.org/software/octave/news/release/2018/08/09/octave-4.4.1-released.html
- Drop obsolete Fix-build-with-Qt-511.patch
- Fix build with Qt 5.12, use qhelpgenerator for qcollectiongenerator
- Stop messing with upstream appdata/desktop files
- Use %%bcond_with/%%bcond_without
- Fix unit tests by increasing JVM stack limit, see https://savannah.gnu.org/bugs/index.php?55395
* Fri Jun 22 2018 dmitry_r@opensuse.org
- Qt5 GUI package requires libQt5Sql5-sqlite [boo#1095605]
* Mon Jun  4 2018 christophe@krop.fr
- Add Fix-build-with-Qt-511.patch.
- Use %%license for license files
* Wed May 16 2018 dmitry_r@opensuse.org
- Update to version 4.4.0
  See https://www.gnu.org/software/octave/NEWS-4.4.html for details
- Drop octave-java-use-source-target-1_6.patch
- Drop SLE11 support (already broken)
- Drop update-alternatives usage
* Mon Mar 19 2018 badshah400@gmail.com
- Update to version 4.2.2:
  * Long list of changes: see
    https://www.gnu.org/software/octave/news/release/2018/03/13/octave-4.2.2-released.html
- Drop octave-also-check-for-qscintilla2_qt5.patch: incorporated
  upstream.
* Mon Oct  2 2017 badshah400@gmail.com
- Add octave-java-use-source-target-1_6.patch: Switch
  source/target to 1.6 from 1.3, to get octave building with java
  9 (for openSUSE > 1320); patch taken from upstream mercurial
  repository [https://savannah.gnu.org/bugs/?51803].
* Wed Aug 23 2017 dmitry_r@opensuse.org
- Fix octave-devel package requirements
- Add %%octave_blas macros
* Mon Aug 21 2017 dmitry_r@opensuse.org
- Move mkoctfile binary to octave-devel package
* Thu Aug 10 2017 dmitry_r@opensuse.org
- Reenable sparce matrix support
- Build with openBLAS library by default, except i*86 architectures
  due to tests failures
* Mon Jul 10 2017 badshah400@gmail.com
- Edit _constraints file to require at least 2GB physical memory,
  builds on 32-bit systems fail otherwise; see
  https://savannah.gnu.org/bugs/index.php?51436; fixes build
  failures on i586 for openSUSE > 1320.
- Drop suitesparse-devel BuildRequires; this pulls in openblas,
  which is not recommended by upstream. See comment #2 in
  https://savannah.gnu.org/bugs/index.php?51436.
* Mon Jun 26 2017 badshah400@gmail.com
- Add octave-also-check-for-qscintilla2_qt5.patch: When checking
  for the availibility of QT5 bindings for scintilla, also check
  for qscintilla2_qt5 (which is the shlib name used by openSUSE),
  otherwise this causes the in-built editor to be disabled; patch
  taken from upstream. Since patch modifies m4 files, regenerate
  configure before executing it (add BuildRequires on automake,
  autoconf and libtool). All changes applied conditionally only
  when building against Qt5.
* Tue Feb 28 2017 dmitry_r@opensuse.org
- Update to version 4.2.1
  * See icluded NEWS file for details
* Tue Nov 15 2016 dmitry_r@opensuse.org
- Update to version 4.2.0
  * See icluded NEWS file for details
* Thu Nov 10 2016 dmitry_r@opensuse.org
- Update to version 4.2.0-rc4
  * See icluded NEWS file for details
* Mon Oct 31 2016 dmitry_r@opensuse.org
- Update to version 4.2.0-rc3
  * See icluded NEWS file for details
  * Drop octave-gui-info-links.patch, octave-gui-utf8.patch
* Thu Oct 27 2016 dmitry_r@opensuse.org
- Fix Qt5-based GUI documentation links
  * octave-gui-info-links.patch
- Fix Qt4-based GUI text encoding [boo#1005431]
  * octave-gui-utf8.patch
* Wed Oct 19 2016 dmitry_r@opensuse.org
- Build Qt5-based GUI for openSUSE Tumbleweed
- Clean build requires
- Move pkg-config file to octave-devel package
* Tue Oct 18 2016 badshah400@gmail.com
- Run %%desktop_database_post(un) and %%icon_theme_cache_post(un)
  for %%post(un) to update the icon theme cache (required whenever
  application installs icons to the hicolor icon dir) and desktop
  database (required whenever application installs a .desktop
  file) when building with GUI enabled.
* Fri Sep 23 2016 dmitry_r@opensuse.org
- Update to version 4.2.0~rc2
  * See icluded NEWS file for details
- Drop obsolete ocatve-evalc.patch
* Sat Sep 17 2016 dmitry_r@opensuse.org
- Fix evalc crash
  * ocatve-evalc.patch
* Sun Sep 11 2016 dmitry_r@opensuse.org
- Update to version 4.2.0~rc1
  * See icluded NEWS file for details
- Drop obsolete octave-gcc6.patch
- Temporary set MALLOC_PERTURB_=0 for tests
* Fri Aug 26 2016 dmitry_r@opensuse.org
- Fix suse-alternative-link-missing [boo#994253]
* Fri Jul 29 2016 dmitry_r@opensuse.org
- Use original appdata file
- Fix SLE12 build
* Thu Jul 28 2016 badshah400@gmail.com
- Update to version 4.0.3:
  * Bug fix release, see
    http://www.gnu.org/software/octave/fixes-4-0-3.html for a full
    list of fixes.
- Add appdata file as source, and install it to
  /usr/share/appdata; this makes octave appear on appstores like
  gnome-software and KDE Discover.
- Rebase octave-gcc6.patch for current version.
* Sat Jun 18 2016 dmitry_r@opensuse.org
- Fix build with GCC6 [boo#985363]
  * octave-gcc6.patch
* Tue Jun  7 2016 dmitry_r@opensuse.org
- Update to version 4.0.2
  * Bugfix release
- Fix SLE12 config
- Use update-alternatives mechanism for octave binary
* Tue Mar 22 2016 dmitry_r@opensuse.org
- Update to version 4.0.1
  * Bugfix release
* Tue Feb 23 2016 ro@suse.de
- vendor is ibm on s390, not suse
* Fri Oct 23 2015 dvaleev@suse.com
- Add disk constraints. Some workers might have enabled build in
  tmpfs. Where the space is limited.
* Sun Sep 13 2015 dmitry_r@opensuse.org
- Fix desktop menu category
* Thu Jul 23 2015 dmitry_r@opensuse.org
- Add build config for openSUSE:42
* Fri May 29 2015 dmitry_r@opensuse.org
- Update to version 4.0.0
  * See icluded NEWS file for details
- Drop obsolete patches:
  * octave-3.8.0-llvm-3.4.patch
  * octave-suitesparse-4.4.patch
  * octave-unzip-info-in-gui.patch
- Add RPM macros to octave-devel package
  * octave.macros
* Mon Feb 23 2015 dmitry_r@opensuse.org
- Fix unzipping compressed info files when running the gui [boo#918942]
  * octave-unzip-info-in-gui.patch
- Disable JIT compilation by default
- Set build settings for SLE11
* Wed Nov 12 2014 dmitry_r@opensuse.org
- Set build settings for SLE12
* Fri Oct 31 2014 dmitry_r@opensuse.org
- Fix build with latest SuiteSparse library
  * octave-suitesparse-4.4.patch
- Restore SuiteSparse linking hack for openSUSE <= 13.1
* Sat Oct 11 2014 dmueller@suse.com
- fix filelist on armv6/7hl: triplet is gnueabi, not gnu
* Fri Aug 22 2014 dmitry_r@opensuse.org
- Move GUI localization files to octave-gui package
* Fri Aug 15 2014 dmitry_r@opensuse.org
- Fix runtime dependencies: makeinfo instead of texinfo [bnc#892123]
* Wed Aug 13 2014 dmitry_r@opensuse.org
- Update to version 3.8.2
  * Bugfix release, see included ChangeLog file for details
- Drop suitesparse linking hack [bnc#883683]
* Thu Jun 19 2014 dmitry_r@opensuse.org
- Build with FFTW3 multi-threading support
* Tue Apr 22 2014 dmitry_r@opensuse.org
- Enable OpenMP support
* Fri Mar  7 2014 dmitry_r@opensuse.org
- Update to version 3.8.1
  * Bugfix release, see included ChangeLog file for details
  * removed obsolete octave-3.8.0-gzip-compressed-info.patch
- Disable JIT support for non-x86 architectures
* Sat Feb  1 2014 dmitry_r@opensuse.org
- Fix build with LLVM-3.4
  * octave-3.8.0-llvm-3.4.patch
* Thu Jan  2 2014 dmitry_r@opensuse.org
- Fix loading gzip-compressed info files [bnc#857130]
  * octave-3.8.0-gzip-compressed-info.patch
* Mon Dec 30 2013 dmitry_r@opensuse.org
- Add octave-gui as recommended dependence
- Build with jit support
* Sat Dec 28 2013 dmitry_r@opensuse.org
- Update to version 3.8.0
  * See included NEWS and ChangeLog files for details
- Removed obsolete octave-gcc48-mex_remove_externc.patch
* Sun Jul 28 2013 klaussfreire@gmail.com
- Added octave-gcc48-mex_remove_externc, fixes an issue when
  building packages that include mex.h in gcc 4.8
* Wed May  1 2013 dmitry_r@opensuse.org
- Cleanup recommended packages
* Sat Mar 30 2013 dmitry_r@opensuse.org
- Move documentation to octave-doc package
* Thu Mar 14 2013 pgajdos@suse.com
- minor spec file adjustment
* Fri Mar  8 2013 dmitry_r@opensuse.org
- Fix native graphics support for openSUSE 12.3 [bnc#808530]
* Thu Feb 28 2013 dmitry_r@opensuse.org
- Update to version 3.6.4
  * See included ChangeLog file for details
- Enable post build tests
- Enable paralell build
* Thu Feb  7 2013 dmitry_r@opensuse.org
- Enable native graphics
* Wed Dec 12 2012 pgajdos@suse.com
- install octave.pc file [bnc#793682]
  + source octave.pc.in
* Mon Dec  3 2012 pgajdos@suse.com
- local rc file into /etc (Dieter Jurzitza) [bnc#792507]
* Tue Oct 30 2012 dieter.jurzitza@t-online.de
- add makeinfo to BuildRequires
* Fri Oct 26 2012 badshah400@gmail.com
- Update to version 3.6.3:
  + Too many bug-fixes to list, see installed CHANGELOG file for a
    list.
- Drop octave-gets.patch, incorporated upstream.
* Tue Sep 18 2012 idonmez@suse.com
- Add BuildRequires on texinfo (instead of makeinfo) and texlive-dvips
* Tue Sep 11 2012 pgajdos@suse.com
- fix /etc/ld.so.conf.d/octave.conf [bnc#779072]
* Sat Sep  8 2012 idonmez@suse.com
- Add explicit build dependency on makeinfo
* Tue Aug 21 2012 dmitry@roshchin.org
- Change packages directories owner
* Sun Aug 19 2012 scorot@free.fr
- fix umfpack and cholmod linking according to recent suitesparse
  update
- enable arpack support
* Sun Jul 29 2012 aj@suse.de
- Fix build with missing gets declaration (glibc 2.16)
* Fri Jun  1 2012 pgajdos@suse.com
- updated to 3.6.2:
  * fix bad two-arg call of randperm
  * perform convolution properly independently of matrix orientation
  * implement proper op() indexing for diagonal matrices
  * poissrnd should return zero when lambda = 0
  * ensure isargout is not sticky
  * etc., see ChangeLog
* Fri May 11 2012 scorot@free.fr
- remove conditional BuildRequires for blas and lapack since
  recent lapack now build correctly for all suse version
- recommends blas -> blas-devel
* Mon Apr 30 2012 cfarrell@suse.com
- license update: GPL-3.0+
  See COPYING - octave is GPL-3.0+ licensed, not GPL-2.0+
* Mon Apr 16 2012 badshah400@gmail.com
- Spec file cleanup: remove Authors from description, remove
  conditionals referring to obsolete suse_versions.
* Fri Apr 13 2012 badshah400@gmail.com
- Modify BuildRequires to match recent name changes of lapack and
  blas in project.
* Tue Feb 28 2012 pgajdos@suse.com
- build against fltk (native graphics)
- build against arpack
* Mon Feb 27 2012 pgajdos@suse.com
- updated to 3.6.1:
  * removed qhull.patch
* Mon Jan 30 2012 pgajdos@suse.com
- build against 2012.1
* Mon Jan  9 2012 pgajdos@suse.com
- thanks to Martin Helm: remove octave-umfpack.patch and
  use --with-umfpack configure switch instead
* Thu Dec  1 2011 pgajdos@suse.com
- again build against hdf5
* Tue Nov 15 2011 pgajdos@suse.com
- don't build against hdf5 for now, hdf5 is not building against
  12.1 and Factory
* Mon Oct 24 2011 pgajdos@suse.com
- updated to 3.4.3:
  * removed unneeded tar-cond.patch
* Wed Oct 12 2011 pgajdos@suse.com
- build against Mesa-devel and fltk-devel conditional, use gnuplot
  rather
* Fri Oct  7 2011 pgajdos@suse.com
- fixed tar(), see
  http://trac.imagemagick.org/changeset/5359
  * tar-cond.patch
* Wed Oct  5 2011 pgajdos@suse.com
- build against Mesa-devel, fltk-devel -> native graphics
- really build against cxsparse
- build against qrupdate
* Mon Oct  3 2011 pgajdos@suse.com
- really build against umfpack
* Sat Oct  1 2011 pgajdos@suse.com
- build against suitesparse-devel instead of umfpack-devel (umfpack
  is part of suitesparse package from now on)
* Tue Sep 20 2011 pgajdos@suse.com
- build against qhull
* Tue Aug 16 2011 pgajdos@novell.com
- linked against umfpack (thanks to Christof Kauffman for
  notification)
* Tue Jul 26 2011 pgajdos@novell.com
- updated to 3.4.2
* Thu Jun 16 2011 pgajdos@novell.com
- updated to 3.4.1
  * no-return-in-nonvoid.patch
* Sun May 29 2011 werner.ho@gmx.de
- fixed hdf5-devel package name
* Tue Feb 15 2011 pgajdos@suse.cz
- updated to 3.4.0
* Thu Jan 13 2011 pgajdos@suse.cz
- downgrade back to 3.2.4 stable
* Fri Jan  7 2011 pgajdos@suse.cz
- build against GraphicsMagick
- updated to 3.3.54
* Mon Feb 15 2010 pgajdos@suse.cz
- updated to 3.2.4 (see NEWS and ChangeLog)
* Mon Nov 23 2009 pgajdos@suse.cz
- better handling of library path in the specfile [bnc#557340]
* Wed Nov 11 2009 pgajdos@suse.cz
- updated to 3.2.3 (see NEWS and ChangeLog)
- fixed [bnc#552978]
* Thu Aug  6 2009 pgajdos@suse.cz
- updated to 3.2.2
  - bugfix release
* Mon Jun 22 2009 pgajdos@suse.cz
- updated to version 3.2.0 (see NEWS)
* Tue Apr 14 2009 pgajdos@suse.cz
- updated to 3.0.5:
  * last bug-fixing-release
* Thu Mar 19 2009 pgajdos@suse.cz
- removed octave-3.0.3.patch completely [bnc#480571]
* Wed Mar 18 2009 pgajdos@suse.cz
- cstring -> string.h in patch [bnc#480571]
* Thu Feb 26 2009 pgajdos@suse.cz
- added texinfo to the Requires [bnc#285607]
* Mon Jan 26 2009 pgajdos@suse.cz
- added some packages to Recommends [bnc#468395]
* Tue Jan 13 2009 pgajdos@suse.cz
- updated to 3.0.3:
  * next bug-fixing release
* Mon Sep  8 2008 pgajdos@suse.cz
- updated to 3.0.2:
  * next bug-fixing release
* Wed Jul  2 2008 pgajdos@suse.cz
- build againist hdf5 1.8.1 -- using compatibility -DH5_USE_16_API
* Mon Jun 23 2008 pgajdos@suse.cz
- new version 3.0.1:
  * bug-fixing release
* Tue Mar 25 2008 pgajdos@suse.cz
- new version 3.0.0 moved from OBS, project science
  * improved compatibility with Matlab (tm)
  * bugfixes
- newly linked optional libraries: curl, hdf5, glpk
* Mon Nov 19 2007 pgajdos@suse.cz
- %%{_datadir}/octave/site/m/startup/octaverc linked to /etc/octave
  and marked as %%config(noreplace)
- several minor spec file cleanups
* Wed Oct 17 2007 pgajdos@suse.cz
- fixed build with new gcc -- added missing includes
  * missing-includes.patch
* Wed Jul 25 2007 pgajdos@suse.cz
- supressed paralell building which fails at least on some
  architectures
* Wed Jul 11 2007 pgajdos@suse.cz
- updated to 2.9.12 and removed randlib [#279883]
- without-randlib.patch
* Thu Jun 21 2007 pgajdos@suse.cz
- added texinfo to Requires
* Fri May 25 2007 pgajdos@suse.cz
- made subpackage octave-devel
* Sat Apr 21 2007 aj@suse.de
- Use texlive.
* Thu Jun 22 2006 ro@suse.de
- remove selfprovides
* Wed May 24 2006 anicka@suse.cz
- update to 2.1.73
  - bugfix release
* Mon Feb 13 2006 anicka@suse.cz
- require gcc-fortran (fixes #150047)
* Wed Feb  1 2006 anicka@suse.cz
- add -Os to FFLAGS (fixes #136787)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Jan 14 2006 kukuk@suse.de
- Add gmp-devel to nfb
* Thu Jan  5 2006 anicka@suse.cz
- update to 2.1.72
* Mon Nov 14 2005 anicka@suse.cz
- fix build (gcc 4.1)
* Tue Nov  1 2005 anicka@suse.cz
- fix build (move code around in CMatrix.cc)
* Tue Jun 28 2005 anicka@suse.cz
- update to 2.1.71
* Wed May 11 2005 ro@suse.de
- fix build with gcc4
* Mon Apr 18 2005 mcihar@suse.de
- GNU Fortran 77 compiler now requires gmp, let's add it
- still doesn't compile, because GCC: TODO: Functions with alternate entry points
* Tue Dec 21 2004 mcihar@suse.cz
- update to 2.1.64
- do not include info pages, as they are out of date
- string patching was not needed for long time, so drop the patch
* Thu Nov 11 2004 ro@suse.de
- fixed file list
* Wed Aug  4 2004 mcihar@suse.cz
- update to 2.1.57
* Fri Mar  5 2004 mcihar@suse.cz
- really compile with -fno-strict-aliasing
- doesn't need f2c at all
* Fri Mar  5 2004 mcihar@suse.cz
- update to 2.1.55
- fix info pages installation
- add some docs
- use -fno-strict-aliasing
* Fri Jan  9 2004 adrian@suse.de
- add %%run_ldconfig
- use RPM_OPT_FLAGS
* Fri Aug 29 2003 mcihar@suse.cz
- info pages should not be executable
* Wed Aug 13 2003 ro@suse.de
- fix info page installation again (thanks to DJurzitza)
* Wed Jul 30 2003 ro@suse.de
- install more info pages
* Thu Jun 26 2003 ro@suse.de
- remove traces of buildroot from installed files
* Wed Jun 11 2003 ltinkl@suse.cz
- updated sources to version 2.1.49
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Mon Mar  3 2003 ro@suse.de
- added info dir entries
* Tue Feb 25 2003 mcihar@suse.cz
- removed -mminimal-toc as it is now part of RPM_OPT_FLAGS for ppc64
- added gnuplot to requires
* Mon Feb 10 2003 mcihar@suse.cz
- used %%install_info macro (fixes bug #23443)
* Wed Feb  5 2003 mcihar@suse.cz
- removed RPM_OPT_FLAGS="$RPM_OPT_FLAGS -mminimal-toc" for ppc64
  (fixes bug #23266)
- updated to 2.1.44
* Fri Nov 22 2002 mcihar@suse.cz
- updated to 2.1.40, mostly only configure and automake fixes, it
  also fixes sstream and some other smaller issues with gcc 3.3
- fixed multiline string
* Tue Aug  6 2002 mcihar@suse.cz
- updated to 2.1.36
* Sat Jun 29 2002 olh@suse.de
- build with -mminimal-toc on ppc64, use RPM_OPT_FLAGS for CFLAGS
* Tue May 21 2002 ro@suse.de
- call suse_update_config also for kpathsea subdir
* Wed May  8 2002 ro@suse.de
- fix for latest gcc-snapshot
* Fri Apr 19 2002 coolo@suse.de
- updating to octave 2.1.35 as octave 2.0.1[67] were hopeless
  with gcc 3.1 (gave up after 2 days of work)
* Tue May  8 2001 mfabian@suse.de
- bzip2 sources
* Fri May  5 2000 bubnikv@suse.cz
- added buildroot
- /usr/execlib/octave moved to /usr/lib/octave according to FHS 2.1
* Mon Feb 21 2000 ro@suse.de
- update to 2.0.16
* Tue Jan 25 2000 ro@suse.de
- update to 2.0.15
- man,info to /usr/share using macro
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Tue Jul 13 1999 ro@suse.de
- update to 2.0.14
* Thu May 20 1999 ro@suse.de
- use CFLAGS="-D_GNU_SOURCE"
* Mon Nov 23 1998 ro@suse.de
- update to 2.0.13 / builds with glibc
* Tue Oct  6 1998 ro@suse.de
- BETA: added f2c to neededforbuild
* Wed Jan 28 1998 ro@suse.de
- removed libhistory.so & libreadline.so as well and link static
  to these
* Mon Nov 17 1997 bs@suse.de
- removed libhistory.a & libreadline.a from file list.
* Wed Nov 12 1997 ro@suse.de
- minor changes in specfile
  setting host to ARCH-suse-linux
* Mon Nov 10 1997 ro@suse.de
- new version 2.0.9
* Tue Oct  7 1997 ro@suse.de
- prepared spec file
- added README-GCC-2.7.? patches
